import 'package:flutter/material.dart';

// ignore: depend_on_referenced_packages
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class ColorsExample extends StatelessWidget {
  const ColorsExample({Key? key}) : super(key: key);

  Widget _buildColors(MaterialColor color, List<int> variations) {
    if (variations.isEmpty) {
      return Container(
        color: color,
        height: 80.0,
        width: 80.0,
      );
    } else {
      return SingleChildScrollView(
        scrollDirection: Axis.horizontal,
        child: Row(
          children: variations
              .map((variation) => Container(
                    color: color[variation],
                    height: 80.0,
                    width: 80.0,
                    child: Text(
                      variation.toString(),
                      style: SeniorTypography.bodySemiBold(),
                    ),
                  ))
              .toList(),
        ),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Colors',
      child: Padding(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Primary color',
                child: _buildColors(
                  SeniorColors.primaryColor,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Secondary color',
                child: _buildColors(
                  SeniorColors.secondaryColor,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Neutral color',
                child: _buildColors(
                  SeniorColors.neutralColor,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Supporting color',
                child: _buildColors(
                  SeniorColors.supportingColor,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Manchester red color',
                child: _buildColors(
                  SeniorColors.manchesterColorRed,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Manchester orange color',
                child: _buildColors(
                  SeniorColors.manchesterColorOrange,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Manchester yellow color',
                child: _buildColors(
                  SeniorColors.manchesterColorYellow,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Manchester green color',
                child: _buildColors(
                  SeniorColors.manchesterColorGreen,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Manchester blue color',
                child: _buildColors(
                  SeniorColors.manchesterColorBlue,
                  [100, 200, 300, 400, 500, 600, 700, 800, 900],
                ),
              ),
              Panel(
                title: 'Pure white',
                child: _buildColors(
                  SeniorColors.pureWhite,
                  [],
                ),
              ),
              Panel(
                title: 'Pure black',
                child: _buildColors(
                  SeniorColors.pureBlack,
                  [],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
